///
///	@file image.h	@brief image loading header file
///
///	Copyright (c) 2009 by Lutz Sammer.  All Rights Reserved.
///
///	Contributor(s):
///
///	License: AGPLv3
///
///	This program is free software: you can redistribute it and/or modify
///	it under the terms of the GNU Affero General Public License as
///	published by the Free Software Foundation, either version 3 of the
///	License.
///
///	This program is distributed in the hope that it will be useful,
///	but WITHOUT ANY WARRANTY; without even the implied warranty of
///	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
///	GNU Affero General Public License for more details.
///
///	$Id: a6c6f8e3c68eca9bb96b99eb4f1d83b1634a1848 $
//////////////////////////////////////////////////////////////////////////////

/// @addtogroup image
/// @{

#ifdef USE_ICON

//////////////////////////////////////////////////////////////////////////////
//	Declares
//////////////////////////////////////////////////////////////////////////////

/**
**	Image typedef.
*/
typedef struct _image_ Image;

/**
**	Image structure.
*/
struct _image_
{
    uint16_t Width;			///< width of image
    uint16_t Height;			///< height of image
    uint8_t Data[1];			///< image data ARGB 32
};

//////////////////////////////////////////////////////////////////////////////
//	Prototypes
//////////////////////////////////////////////////////////////////////////////

#ifdef USE_JPEG
    /// Load a JPEG image from given file name.
extern Image *ImageLoadJPEG0(const char *name, unsigned, unsigned);
#endif

#ifdef USE_XPM
    /// Create an image from XPM data.
extern Image *ImageFromData(const char *const *);
#endif

    /// Create an image from ARGB data.
extern Image *ImageFromARGB(unsigned, unsigned, const uint32_t *);

    /// Load an image from the specified file.
extern Image *ImageLoadFile(const char *);

    /// Destroy an image.
extern void ImageDel(Image *);

#else // }{ USE_ICON

#endif // } !USE_ICON

/// @}
